@@ -6,13 +6,13 @@ import os
 import os.path
 import datetime
 import tensorflow as tf
-from keras.layers import Input, Dense, Activation, BatchNormalization, Dropout, Lambda, Concatenate, concatenate, Add
-from keras.models import Model, Sequential, load_model
-from keras.callbacks import TensorBoard, ModelCheckpoint, EarlyStopping, ReduceLROnPlateau
-from keras import backend as K
-from keras import optimizers, regularizers, initializers
-from keras.utils import plot_model
-from keras.losses import mse, binary_crossentropy
+from tensorflow.keras.layers import Input, Dense, Activation, BatchNormalization, Dropout, Lambda, Concatenate, concatenate, Add
+from tensorflow.keras.models import Model, Sequential, load_model
+from tensorflow.keras.callbacks import TensorBoard, ModelCheckpoint, EarlyStopping, ReduceLROnPlateau
+from tensorflow.keras import backend as K
+from tensorflow.keras import optimizers, regularizers, initializers
+from tensorflow.keras.utils import plot_model
+from tensorflow.keras.losses import mse, binary_crossentropy
 from scipy.sparse import csr_matrix
 
 def sampling(args):
@@ -59,7 +59,7 @@ class VAE:
         self.deterministic = deterministic
         self.save = save
         callbacks = []
-        checkpointer = ModelCheckpoint(filepath=path + "model_{epoch:04d}.h5", verbose=1, save_best_only=True,
+        checkpointer = ModelCheckpoint(filepath=path + "model_{epoch:04d}.h5", verbose=1, save_best_only=False,
                                        save_weights_only=False, period=100)
         reduce_lr = ReduceLROnPlateau(monitor='loss', factor=0.8, patience=patience_lr, min_lr=0.0001)
         early_stop = EarlyStopping(monitor='loss', patience=patience_es)
@@ -527,10 +527,10 @@ class VIPCCA(object):
     method: string, optional (default: 'lognorm')
         the normalization method for input data, one of {"qqnorm","count", other}.
 
-    batch_input_size: int, optional (default: 16)
+    batch_input_size: int, optional (default: 128)
         the length of the batch vector that concatenate with the input layer.
 
-    batch_input_size2: int, optional (default: 8)
+    batch_input_size2: int, optional (default: 16)
         the length of the batch vector that concatenate with the latent layer.
 
     activation: string, optional (default: "softplus")
@@ -542,7 +542,7 @@ class VIPCCA(object):
     hidden_layers: list, optional (default: [128,64,32,16])
         Number of hidden layer neurons in the model
 
-    lambda_regulizer: double, optional (default: 1.0)
+    lambda_regulizer: double, optional (default: 5.0)
         The coefficient multiplied by KL_loss
 
     initializer: string, optional (default: "glorot_uniform")
@@ -571,12 +571,12 @@ class VIPCCA(object):
                  split_by="_batch",
                  method="lognorm",
                  hvg=True,
-                 batch_input_size=16,
-                 batch_input_size2=8,
+                 batch_input_size=128,
+                 batch_input_size2=16,
                  activation="softplus",
                  dropout_rate=0.01,
                  hidden_layers=[128, 64, 32, 16],
-                 lambda_regulizer=1.0,
+                 lambda_regulizer=5.0,
                  initializer="glorot_uniform",
                  l1_l2=(0.0, 0.0),
                  mode="CVAE",
@@ -678,7 +678,8 @@ class VIPCCA(object):
 
         Returns
         -------
-        AnnData
+        :class:`~anndata.AnnData`
+		    adata produced by function self.conf.net.integrate(self.conf.adata_all, save=self.conf.save)
         """
         self.build()
         self.conf.net.train(self.conf.adata_all, epochs=self.conf.epochs, model_file=self.conf.model_file)
